@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2020, TomTom (http://tomtom.com).
+# Copyright (C) 2019-2021, TomTom (http://tomtom.com).
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
 # limitations under the License.
 """Models of API reference elements."""
 
-from abc import ABC, abstractmethod
+from abc import ABC
 from typing import List, Optional
 
 
@@ -66,43 +66,14 @@ class ReferableElement(ModelBase):
         return hash((self.id, self.name, self.full_name, self.language, self.kind))
 
 
-class TypeRefBase(ModelBase, ABC):
-    """Base class for references to types.
+class TypeRef(ModelBase):
+    """Reference to a type.
+
     Attributes:
         id:        Unique identifier of the type.
         name:      Name of the type.
         language:  Language the type is written in.
         namespace: Namespace, or package, from which the type is referenced.
-    """
-    # doxygen based fields
-    id: Optional[str] = None
-    name: str
-    # custom fields
-    language: str
-    namespace: Optional[str] = None
-
-    def __init__(self, language: str = "", name: str = "", **kwargs):
-        super().__init__(**kwargs)
-        self.language = language
-        self.name = name
-
-    @abstractmethod
-    def resolve(self, reference_target: ReferableElement) -> None:
-        pass
-
-    def __eq__(self, other) -> bool:
-        if other is None:
-            return False
-        return ((self.id, self.name, self.language,
-                 self.namespace) == (other.id, other.name, other.language, other.namespace))
-
-
-class TypeRef(TypeRefBase):
-    """Reference to a type.
-
-    Representation of doxygen type linkedTextType
-
-    Attributes:
         kind:      Kind of language element.
         prefix:    Qualifiers prefixing the type.
         suffix:    Qualifiers suffixing the type.
@@ -110,19 +81,26 @@ class TypeRef(TypeRefBase):
         args:      Arguments for function like types. None if no arguments, an empty list if zero
                        arguments.
         returns:   Return type in case of closure types.
+        prot:      Protection level of the referenced type.
     """
 
-    # doxygen based fields
+    id: Optional[str] = None
+    name: str
+    language: str
+    namespace: Optional[str] = None
     kind: Optional[str] = None
-    # custom fields
+
     prefix: Optional[str] = None
     suffix: Optional[str] = None
     nested: Optional[List["TypeRef"]] = None
     args: Optional[List["Parameter"]] = None
     returns: Optional["TypeRef"] = None
+    prot: Optional[str] = None
 
     def __init__(self, language: str = "", name: str = "", **kwargs):
-        super().__init__(language, name, **kwargs)
+        super().__init__(**kwargs)
+        self.language = language
+        self.name = name
 
     def __str__(self) -> str:
         nested_str = ""
@@ -140,10 +118,11 @@ class TypeRef(TypeRefBase):
     def __eq__(self, other) -> bool:
         if other is None:
             return False
-        return (super().__eq__(other)
-                and (self.kind, self.prefix, self.suffix, self.nested, self.args, self.returns)
-                == (other.kind, other.prefix, other.suffix, other.nested, other.args,
-                    other.returns))
+        return ((self.id, self.name, self.language, self.namespace, self.kind, self.prefix,
+                 self.suffix, self.nested, self.args, self.returns,
+                 self.prot) == (other.id, other.name, other.language, other.namespace, other.kind,
+                                other.prefix, other.suffix, other.nested, other.args, other.returns,
+                                other.prot))
 
 
 class Parameter(ModelBase):
@@ -213,53 +192,6 @@ class ThrowsClause(ModelBase):
         return (self.type, self.description) == (other.type, other.description)
 
 
-class EnumValue(ReferableElement):
-    """Single value in an enum type.
-
-    Attributes:
-        initializer: Value assigned to the enum.
-        brief:       Brief description of the enum value.
-        description: Full description of the enum value.
-    """
-
-    # doxygen based fields
-    initializer: str = ""
-    brief: str = ""
-    description: str = ""
-
-    # custom fields
-    kind: str = "enumvalue"
-
-    def __eq__(self, other) -> bool:
-        if other is None:
-            return False
-        return (super().__eq__(other) and (self.initializer, self.brief, self.description)
-                == (other.initializer, other.brief, other.description))
-
-
-class InnerTypeReference(TypeRefBase):
-    """Representation of a reference to a type/class/member in the documentation.
-
-    It can be used to reflect Doxygen::xml type refType.
-
-    Attributes:
-        referred_object: Element being referenced.
-        prot:            Protection level of the inner type.
-    """
-
-    referred_object: Optional["Compound"] = None
-    prot: str = ""
-
-    def resolve(self, reference_target):
-        self.referred_object = reference_target
-
-    def __eq__(self, other) -> bool:
-        if other is None:
-            return False
-        return (super().__eq__(other)
-                and (self.referred_object, self.prot) == (other.referred_object, other.prot))
-
-
 class Compound(ReferableElement):
     """Compound object. E.g. a class or enum.
 
@@ -267,17 +199,25 @@ class Compound(ReferableElement):
 
     Attributes:
         members:       List of members in the compound.
-        inner_classes: References to inner types.
-        brief:         Brief description of the compound.
-        description:   Full description of the compound.
-        enumvalues:    List of enum values contained in the compound.
+        params:        List of parameters.
+        exceptions:    List of exceptions that can be thrown.
+        returns:       Return value.
         include:       Name of the include (file) required to use this compound.
         namespace:     Namespace, or package, the compound is contained in.
+        prot:          Protection or visibility level.
+        definition:    Full definition in source code.
+        args:          All arguments as in source code.
+        initializer:   Initial value assignment.
+        brief:         Brief description of the compound.
+        description:   Full description of the compound.
+        static:        True if this is marked as static.
+        const:         True if this is marked as const.
+        deleted:       True if this is marked as deleted.
+        default:       True if this is marked as default.
+        constexpr:     True if this is marked as constexpr.
     """
 
     members: List["Compound"]
-    inner_classes: List[InnerTypeReference]
-    enumvalues: List[EnumValue]
     params: List[Parameter]
     exceptions: List[ThrowsClause]
     returns: Optional[ReturnValue] = None
@@ -288,6 +228,7 @@ class Compound(ReferableElement):
     prot: str = ""
     definition: str = ""
     args: str = ""
+    initializer: str = ""
 
     brief: str = ""
     description: str = ""
@@ -302,15 +243,11 @@ class Compound(ReferableElement):
                  language: str = "",
                  *,
                  members: Optional[List["Compound"]] = None,
-                 inner_classes: Optional[List[InnerTypeReference]] = None,
-                 enumvalues: Optional[List[EnumValue]] = None,
                  params: Optional[List[Parameter]] = None,
                  exceptions: Optional[List[ThrowsClause]] = None,
                  **kwargs):
         super().__init__(language, **kwargs)
         self.members = members or []
-        self.inner_classes = inner_classes or []
-        self.enumvalues = enumvalues or []
         self.params = params or []
         self.exceptions = exceptions or []
 
@@ -321,14 +258,14 @@ class Compound(ReferableElement):
         if other is None:
             return False
         return (super().__eq__(other)
-                and (self.members, self.inner_classes, self.enumvalues, self.params,
-                     self.exceptions, self.returns, self.include, self.namespace, self.prot,
-                     self.definition, self.args, self.brief, self.description, self.static,
-                     self.const, self.deleted, self.default, self.constexpr)
-                == (other.members, other.inner_classes, other.enumvalues, other.params,
-                    other.exceptions, other.returns, other.include, other.namespace, other.prot,
-                    other.definition, other.args, other.brief, other.description, other.static,
-                    other.const, other.deleted, other.default, other.constexpr))
+                and (self.members, self.params, self.exceptions, self.returns, self.include,
+                     self.namespace, self.prot, self.definition, self.args, self.initializer,
+                     self.brief, self.description, self.static, self.const, self.deleted,
+                     self.default, self.constexpr)
+                == (other.members, other.params, other.exceptions, other.returns, other.include,
+                    other.namespace, other.prot, other.definition, other.args, other.initializer,
+                    other.brief, other.description, other.static, other.const, other.deleted,
+                    other.default, other.constexpr))
 
     def __hash__(self):
         return super().__hash__()
