@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2020, TomTom (http://tomtom.com).
+# Copyright (C) 2019-2021, TomTom (http://tomtom.com).
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,14 +25,24 @@ class TemplateHelper:
     element: Optional[Compound]
     insert_filter: Optional[InsertionFilter]
 
-    NESTED_START: str = "&lt;"
-    NESTED_END: str = "&gt;"
+    NESTED_START: str = "<"
+    NESTED_END: str = ">"
     ARGS_START: str = "("
     ARGS_END: str = ")"
     ARGS_BEFORE_TYPE = False
     ARGS_TO_TYPE = ""
     PARAM_NAME_FIRST = False
     PARAM_NAME_SEP = " "
+    SIMPLE_ENCLOSED_TYPES = (
+        "typedef",
+        "enum",
+    )
+    COMPLEX_ENCLOSED_TYPES = (
+        "class",
+        "interface",
+        "protocol",
+        "struct",
+    )
 
     def __init__(self,
                  api: Api,
@@ -189,14 +199,14 @@ class TemplateHelper:
         assert self.insert_filter is not None
 
         return (m for m in self.insert_filter.members(self.element)
-                if m.prot == prot and m.kind in ("enum", "typedef"))
+                if m.prot == prot and m.kind in self.SIMPLE_ENCLOSED_TYPES)
 
     def complex_enclosed_types(self, prot: str) -> Iterator[Compound]:
         assert self.element is not None
         assert self.insert_filter is not None
 
-        return (m.referred_object for m in self.insert_filter.inner_classes(self.element)
-                if m.referred_object is not None and m.prot == prot)
+        return (m for m in self.insert_filter.members(self.element)
+                if m.prot == prot and m.kind in self.COMPLEX_ENCLOSED_TYPES)
 
     def variables(self, prot: str) -> Iterator[Compound]:
         assert self.element is not None
@@ -212,6 +222,13 @@ class TemplateHelper:
         return (m for m in self.insert_filter.members(self.element)
                 if m.kind == "property" and m.prot == prot)
 
+    def enum_values(self, prot: str) -> Iterator[Compound]:
+        assert self.element is not None
+        assert self.insert_filter is not None
+
+        return (m for m in self.insert_filter.members(self.element)
+                if m.prot == prot and m.kind == "enumvalue")
+
 
 def has(elements):
     return any(True for _ in elements)
