@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2020, TomTom (http://tomtom.com).
+# Copyright (C) 2019-2021, TomTom (http://tomtom.com).
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,7 +31,6 @@ def test_parse_cpp_class(api_reference):
     assert cpp_class.namespace == "asciidoxy::geometry"
 
     assert len(cpp_class.members) == 15
-    assert len(cpp_class.enumvalues) == 0
 
     member_names = sorted(m.name for m in cpp_class.members)
     assert member_names == sorted([
@@ -59,19 +58,18 @@ def test_parse_cpp_class_with_nested_class(api_reference):
     assert cpp_class is not None
     assert cpp_class.id == "cpp-classasciidoxy_1_1traffic_1_1_traffic_event"
     assert cpp_class.namespace == "asciidoxy::traffic"
-    assert len(cpp_class.inner_classes) == 1
 
-    nested_class = cpp_class.inner_classes[0]
-    assert nested_class.name == "asciidoxy::traffic::TrafficEvent::TrafficEventData"
+    inner_classes = [m for m in cpp_class.members if m.kind == "struct"]
+    assert len(inner_classes) == 1
+
+    nested_class = inner_classes[0]
+    assert nested_class.full_name == "asciidoxy::traffic::TrafficEvent::TrafficEventData"
     assert nested_class.namespace == "asciidoxy::traffic::TrafficEvent"
     assert nested_class.id == ("cpp-structasciidoxy_1_1traffic_1_1_traffic_event_1_1_traffic_"
                                "event_data")
     assert nested_class.language == "cpp"
     assert nested_class.prot == "public"
 
-    assert nested_class.referred_object is not None
-    assert nested_class.referred_object.id == nested_class.id
-
 
 @pytest.mark.parametrize("api_reference_set", [["cpp/default"]])
 def test_parse_cpp_class__ignore_friend_declarations(api_reference):
@@ -104,7 +102,6 @@ def test_parse_cpp_member_function_no_return_value(api_reference):
 
     assert len(member.params) == 0
     assert len(member.exceptions) == 0
-    assert len(member.enumvalues) == 0
     assert member.returns is None
 
 
@@ -132,7 +129,6 @@ def test_parse_cpp_member_function_only_return_value(api_reference):
 
     assert len(member.params) == 0
     assert len(member.exceptions) == 0
-    assert len(member.enumvalues) == 0
 
     assert member.returns is not None
     assert member.returns.description == "True if valid, false if not."
@@ -170,7 +166,6 @@ def test_parse_cpp_member_function_params_and_return_value(api_reference):
     assert member.const is False
 
     assert len(member.exceptions) == 0
-    assert len(member.enumvalues) == 0
 
     assert len(member.params) == 2
     param1, param2 = member.params
@@ -263,8 +258,8 @@ def test_parse_cpp_member_enum(api_reference):
             "The more severe the traffic event, the more likely it is to have a large delay.")
     assert member.include == "traffic_event.hpp"
 
-    assert len(member.enumvalues) == 4
-    enum_value = [e for e in member.enumvalues if e.name == "High"][0]
+    assert len(member.members) == 4
+    enum_value = [e for e in member.members if e.name == "High"][0]
     assert enum_value.id == ("cpp-classasciidoxy_1_1traffic_1_1_traffic_event_"
                              "1a47c51b1f1f014cb943377fb67ad903b9a655d20c1ca69519ca647684edbb2db35")
     assert enum_value.name == "High"
@@ -274,6 +269,7 @@ def test_parse_cpp_member_enum(api_reference):
     assert enum_value.brief == "High severity."
     assert enum_value.description == "Better stay away here."
     assert enum_value.kind == "enumvalue"
+    assert enum_value.prot == "public"
 
 
 @pytest.mark.parametrize("api_reference_set", [["cpp/default"]])
