@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2020, TomTom (http://tomtom.com).
+# Copyright (C) 2019-2021, TomTom (http://tomtom.com).
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,7 +29,7 @@ from asciidoxy.generator.errors import (AmbiguousReferenceError, ConsistencyErro
                                         IncludeFileNotFoundError, IncompatibleVersionError,
                                         InvalidApiCallError, MissingPackageError,
                                         MissingPackageFileError, ReferenceNotFoundError,
-                                        TemplateMissingError)
+                                        TemplateMissingError, UnknownAnchorError)
 from asciidoxy.packaging import Package, PackageManager
 
 from asciidoxy import __version__
@@ -402,47 +402,47 @@ def test_insert_class__global_filter_members__extend(generating_api):
 
 def test_link_class(generating_api):
     result = generating_api.link("asciidoxy::geometry::Coordinate")
-    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[+++Coordinate+++]")
+    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[++Coordinate++]")
 
 
 def test_link_function(generating_api):
     result = generating_api.link("asciidoxy::geometry::Coordinate::IsValid")
     assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate_"
-                      "1a8d7e0eac29549fa4666093e36914deac[+++IsValid+++]")
+                      "1a8d7e0eac29549fa4666093e36914deac[++IsValid++]")
 
 
 def test_link_class_explicit(generating_api):
     result = generating_api.link("asciidoxy::geometry::Coordinate", kind="class")
-    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[+++Coordinate+++]")
+    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[++Coordinate++]")
 
 
 def test_link_function_explicit(generating_api):
     result = generating_api.link("asciidoxy::geometry::Coordinate::IsValid", kind="function")
     assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate_"
-                      "1a8d7e0eac29549fa4666093e36914deac[+++IsValid+++]")
+                      "1a8d7e0eac29549fa4666093e36914deac[++IsValid++]")
 
 
 def test_link_class_with_full_name(generating_api):
     result = generating_api.link("asciidoxy::geometry::Coordinate", full_name=True)
-    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[+++asciidoxy::geometry::"
-                      "Coordinate+++]")
+    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[++asciidoxy::geometry::"
+                      "Coordinate++]")
 
 
 def test_link_class_with_custom_text(generating_api):
     result = generating_api.link("asciidoxy::geometry::Coordinate", text="LINK HERE")
-    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[+++LINK HERE+++]")
+    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[++LINK HERE++]")
 
 
 def test_link_class_with_alternative_language_tag(generating_api):
     result = generating_api.link("asciidoxy::geometry::Coordinate", lang="c++")
-    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[+++Coordinate+++]")
+    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[++Coordinate++]")
 
 
 def test_link_class_with_transcoding(generating_api):
     generating_api.language("kotlin", source="java")
     result = generating_api.link("com.asciidoxy.geometry.Coordinate")
     assert result == ("xref:kotlin-classcom_1_1asciidoxy_1_1geometry_1_1_coordinate"
-                      "[+++Coordinate+++]")
+                      "[++Coordinate++]")
 
 
 def test_link_class_with_transcoding__not_found_warning(generating_api):
@@ -494,24 +494,24 @@ def test_cross_document_ref__with_absolute_path(test_data_builder, tdb_single_an
             api.cross_document_ref(target_file, anchor="anchor")
 
 
-def test_cross_document_ref__requires_filename_or_packagename(test_data_builder,
-                                                              tdb_single_and_multipage):
+def test_cross_document_ref__requires_filename_packagename_or_anchor(test_data_builder,
+                                                                     tdb_single_and_multipage):
     test_data_builder.add_input_file("input.adoc")
     test_data_builder.add_include_file("includes/other_file.adoc")
 
     for api in test_data_builder.apis():
         with pytest.raises(InvalidApiCallError):
-            api.cross_document_ref(anchor="anchor")
+            api.cross_document_ref(link_text="text")
 
 
-def test_cross_document_ref__requires_filename_or_packagename_not_empty(
+def test_cross_document_ref__requires_filename_packagename_or_anchor_not_empty(
         test_data_builder, tdb_single_and_multipage):
     test_data_builder.add_input_file("input.adoc")
     test_data_builder.add_include_file("includes/other_file.adoc")
 
     for api in test_data_builder.apis():
         with pytest.raises(InvalidApiCallError):
-            api.cross_document_ref("", package_name="", anchor="anchor")
+            api.cross_document_ref("", package_name="", anchor="", link_text="text")
 
 
 def test_cross_document_ref__file_not_in_workdirectory(test_data_builder, tdb_single_and_multipage,
@@ -708,6 +708,7 @@ def test_cross_document_ref__document_not_in_tree(test_data_builder, tdb_single_
             result = api.cross_document_ref("other_dir/include.adoc",
                                             package_name="package",
                                             link_text="bla")
+            # TODO: Fix this!
             if isinstance(api, GeneratingApi):
                 assert result == "<<../other_dir/include.adoc#,bla>>"
         else:
@@ -717,6 +718,130 @@ def test_cross_document_ref__document_not_in_tree(test_data_builder, tdb_single_
                                        link_text="bla")
 
 
+def test_anchor(test_data_builder, tdb_single_and_multipage):
+    test_data_builder.add_input_file("input.adoc")
+
+    for api in test_data_builder.apis():
+        result = api.anchor("my-anchor", link_text="anchor text")
+        if isinstance(api, PreprocessingApi):
+            assert result == ""
+        else:
+            assert result == "[[my-anchor,anchor text]]"
+
+
+def test_anchor__no_link_text(test_data_builder, tdb_single_and_multipage):
+    test_data_builder.add_input_file("input.adoc")
+
+    for api in test_data_builder.apis():
+        result = api.anchor("my-anchor")
+        if isinstance(api, PreprocessingApi):
+            assert result == ""
+        else:
+            assert result == "[[my-anchor]]"
+
+
+def test_cross_document_ref__flexible_anchor__same_package(test_data_builder,
+                                                           tdb_single_and_multipage):
+    input_file = test_data_builder.add_input_file("input.adoc")
+    include_file = test_data_builder.add_include_file("include.adoc")
+
+    for api in test_data_builder.apis():
+        api._current_file = include_file
+        api.anchor("my-anchor", link_text="my anchor link text")
+
+        api._current_file = input_file
+        result = api.cross_document_ref(anchor="my-anchor")
+        if isinstance(api, PreprocessingApi):
+            assert result == ""
+        else:
+            if tdb_single_and_multipage:
+                assert result == "<<include.adoc#my-anchor,my anchor link text>>"
+            else:
+                assert result == "<<.asciidoxy.include.adoc#my-anchor,my anchor link text>>"
+
+
+def test_cross_document_ref__flexible_anchor__other_package(test_data_builder,
+                                                            tdb_single_and_multipage):
+    input_file = test_data_builder.add_input_file("input.adoc")
+    include_file = test_data_builder.add_package_file("pacA", "include.adoc")
+
+    for api in test_data_builder.apis():
+        api._current_file = include_file
+        api.anchor("my-anchor", link_text="my anchor link text")
+
+        api._current_file = input_file
+        result = api.cross_document_ref(anchor="my-anchor")
+        if isinstance(api, PreprocessingApi):
+            assert result == ""
+        else:
+            if tdb_single_and_multipage:
+                assert result == "<<include.adoc#my-anchor,my anchor link text>>"
+            else:
+                assert result == "<<.asciidoxy.include.adoc#my-anchor,my anchor link text>>"
+
+
+def test_cross_document_ref__flexible_anchor__link_text(test_data_builder,
+                                                        tdb_single_and_multipage):
+    input_file = test_data_builder.add_input_file("input.adoc")
+    include_file = test_data_builder.add_include_file("include.adoc")
+
+    for api in test_data_builder.apis():
+        api._current_file = include_file
+        api.anchor("my-anchor", link_text="my anchor link text")
+
+        api._current_file = input_file
+        result = api.cross_document_ref(anchor="my-anchor", link_text="other text")
+        if isinstance(api, PreprocessingApi):
+            assert result == ""
+        else:
+            if tdb_single_and_multipage:
+                assert result == "<<include.adoc#my-anchor,other text>>"
+            else:
+                assert result == "<<.asciidoxy.include.adoc#my-anchor,other text>>"
+
+
+def test_cross_document_ref__flexible_anchor__no_link_text(test_data_builder,
+                                                           tdb_single_and_multipage):
+    input_file = test_data_builder.add_input_file("input.adoc")
+    include_file = test_data_builder.add_include_file("include.adoc")
+
+    for api in test_data_builder.apis():
+        api._current_file = include_file
+        api.anchor("my-anchor")
+
+        api._current_file = input_file
+        result = api.cross_document_ref(anchor="my-anchor")
+        if isinstance(api, PreprocessingApi):
+            assert result == ""
+        else:
+            if tdb_single_and_multipage:
+                assert result == "<<include.adoc#my-anchor,my-anchor>>"
+            else:
+                assert result == "<<.asciidoxy.include.adoc#my-anchor,my-anchor>>"
+
+
+def test_cross_document_ref__flexible_anchor__missing_anchor(test_data_builder,
+                                                             tdb_single_and_multipage,
+                                                             tdb_warnings_are_and_are_not_errors):
+    test_data_builder.add_input_file("input.adoc")
+    test_data_builder.add_include_file("include.adoc")
+
+    for api in test_data_builder.apis():
+        if tdb_warnings_are_and_are_not_errors and isinstance(api, GeneratingApi):
+            with pytest.raises(UnknownAnchorError):
+                api.cross_document_ref(anchor="my-anchor")
+
+        else:
+            result = api.cross_document_ref(anchor="my-anchor")
+            if isinstance(api, PreprocessingApi):
+                assert result == ""
+            else:
+                if tdb_single_and_multipage:
+                    assert result == "<<input.adoc#my-anchor,my-anchor>>"
+                else:
+                    assert result == "<<.asciidoxy.input.adoc#my-anchor,my-anchor>>"
+
+
 def test_include__relative_path(test_data_builder):
     input_file = test_data_builder.add_input_file("input.adoc")
     test_data_builder.add_include_file("includes/another_file.adoc")
@@ -1247,7 +1372,7 @@ def test_context_link_to_element_singlepage(context, generating_api):
     link_text = "Link"
     context.inserted[element_id] = context.current_document.in_file.parent / file_containing_element
     assert generating_api.link_to_element(element_id,
-                                          link_text) == f"xref:{element_id}[+++{link_text}+++]"
+                                          link_text) == f"xref:{element_id}[++{link_text}++]"
 
 
 def test_context_link_to_element_multipage(context, multipage, generating_api):
@@ -1256,7 +1381,7 @@ def test_context_link_to_element_multipage(context, multipage, generating_api):
     link_text = "Link"
     context.inserted[element_id] = context.current_document.in_file.parent / file_containing_element
     assert (generating_api.link_to_element(
-        element_id, link_text) == f"xref:{file_containing_element}#{element_id}[+++{link_text}+++]")
+        element_id, link_text) == f"xref:{file_containing_element}#{element_id}[++{link_text}++]")
 
 
 def test_context_link_to_element_multipage_element_in_the_same_document(
@@ -1265,7 +1390,7 @@ def test_context_link_to_element_multipage_element_in_the_same_document(
     link_text = "Link"
     context.inserted[element_id] = context.current_document.in_file
     assert (generating_api.link_to_element(element_id,
-                                           link_text) == f"xref:{element_id}[+++{link_text}+++]")
+                                           link_text) == f"xref:{element_id}[++{link_text}++]")
 
 
 def test_context_link_to_element_element_not_inserted(context, single_and_multipage,
@@ -1274,7 +1399,7 @@ def test_context_link_to_element_element_not_inserted(context, single_and_multip
     link_text = "Link"
     assert element_id not in context.inserted
     assert generating_api.link_to_element(element_id,
-                                          link_text) == f"xref:{element_id}[+++{link_text}+++]"
+                                          link_text) == f"xref:{element_id}[++{link_text}++]"
 
 
 def test_api_proxy__filter(generating_api):
@@ -1305,13 +1430,13 @@ def test_api_proxy__insert_class(generating_api):
 def test_api_proxy__link(generating_api):
     api = ApiProxy(generating_api)
     result = api.link("asciidoxy::geometry::Coordinate")
-    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[+++Coordinate+++]")
+    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[++Coordinate++]")
 
 
 def test_api_proxy__link_class(generating_api):
     api = ApiProxy(generating_api)
     result = api.link_class("asciidoxy::geometry::Coordinate")
-    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[+++Coordinate+++]")
+    assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[++Coordinate++]")
 
 
 def test_api_proxy__cross_document_ref(test_data_builder, tdb_single_and_multipage):
