@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2020, TomTom (http://tomtom.com).
+# Copyright (C) 2019-2021, TomTom (http://tomtom.com).
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,9 +38,9 @@ def python_class():
     builder.member_variable(name="public_variable"),
     builder.member_variable(name="_private_variable"),
     builder.member_variable(name="__mangled_private_variable"),
-    builder.inner_class(name="NestedClass"),
-    builder.inner_class(name="_PrivateNestedClass"),
-    builder.inner_class(name="__MangledPrivateNestedClass"),
+    builder.simple_member(kind="class", prot="public", name="NestedClass"),
+    builder.simple_member(kind="class", prot="public", name="_PrivateNestedClass"),
+    builder.simple_member(kind="class", prot="public", name="__MangledPrivateNestedClass"),
 
     return builder.compound
 
@@ -188,13 +188,13 @@ def test_public_enclosed_types__no_filter(helper):
 
 
 def test_public_enclosed_types__filter_match(helper):
-    helper.insert_filter = InsertionFilter(inner_classes="ALL")
+    helper.insert_filter = InsertionFilter(members="ALL")
     result = list(m.name for m in helper.complex_enclosed_types(prot="public"))
     assert sorted(result) == sorted(["NestedClass"])
 
 
 def test_public_enclosed_types__filter_no_match(helper):
-    helper.insert_filter = InsertionFilter(inner_classes="NONE")
+    helper.insert_filter = InsertionFilter(members="NONE")
     result = list(m.name for m in helper.complex_enclosed_types(prot="public"))
     assert not result
 
@@ -334,7 +334,7 @@ def test_method_signature__ignore_return_type_xref_length(helper):
     method.params[0].type = TypeRef("python", "int")
 
     assert (helper.method_signature(method) ==
-            f"def ShortMethod(value: int) -> xref:{'ab' * 80}[+++Type+++]")
+            f"def ShortMethod(value: int) -> xref:{'ab' * 80}[++Type++]")
 
 
 def test_method_signature__ignore_param_type_xref_length(helper):
@@ -350,7 +350,7 @@ def test_method_signature__ignore_param_type_xref_length(helper):
     method.params[0].type.id = "ab" * 80
 
     assert (helper.method_signature(method) ==
-            f"def ShortMethod(value: xref:{'ab' * 80}[+++int+++]) -> None")
+            f"def ShortMethod(value: xref:{'ab' * 80}[++int++]) -> None")
 
 
 def test_parameter(helper):
@@ -364,7 +364,7 @@ def test_parameter(helper):
     param.default_value = "12"
 
     assert (helper.parameter(
-        param, default_value=True) == "arg: xref:lang-tomtom_1_MyType[+++MyType+++] = 12")
+        param, default_value=True) == "arg: xref:lang-tomtom_1_MyType[++MyType++] = 12")
 
 
 def test_parameter__self(helper):
